@@ -342,7 +342,8 @@ class SyncableAccount(Account):
             # Iterate through all folders on the remote repo and sync.
             for remotefolder in remoterepos.getfolders():
                 # Check for CTRL-C or SIGTERM.
-                if Account.abort_NOW_signal.is_set(): break
+                if Account.abort_NOW_signal.is_set():
+                    break
 
                 if not remotefolder.sync_this:
                     self.ui.debug('', "Not syncing filtered folder '%s'"
@@ -355,10 +356,10 @@ class SyncableAccount(Account):
                 sep = localrepos.getsep()
                 if (sep != os.path.sep and
                     sep != remoterepos.getsep() and
-                    sep in remotefolder.getvisiblename()):
-                    self.ui.warn('', "Ignoring folder %s due to unsupported "
+                    sep in remotefolder.getname()):
+                    self.ui.warn('', "Ignoring folder '%s' due to unsupported "
                         "'%s' character serving as local separator."%
-                        (remotefolder.getvisiblename(), localrepos.getsep()))
+                        (remotefolder.getname(), localrepos.getsep()))
                     continue # Ignore unsupported folder name.
 
                 localfolder = self.get_local_folder(remotefolder)
@@ -605,7 +606,7 @@ def syncfolder(account, remotefolder, quick):
             ui.error(e, exc_info()[2], msg="Aborting sync, folder '%s' "
                      "[acc: '%s']"% (localfolder, account))
     except Exception as e:
-        ui.error(e, msg = "ERROR in syncfolder for %s folder %s: %s"%
+        ui.error(e, msg="ERROR in syncfolder for %s folder %s: %s"%
             (account, remotefolder.getvisiblename(), traceback.format_exc()))
     finally:
         for folder in ["statusfolder", "localfolder", "remotefolder"]:
