@@ -60,7 +60,6 @@ class MaildirFolder(BaseFolder):
     def __init__(self, root, name, sep, repository):
         self.sep = sep # needs to be set before super().__init__
         super(MaildirFolder, self).__init__(name, repository)
-        self.dofsync = self.config.getdefaultboolean("general", "fsync", True)
         self.root = root
         # check if we should use a different infosep to support Win file systems
         self.wincompatible = self.config.getdefaultboolean(
@@ -330,7 +329,7 @@ class MaildirFolder(BaseFolder):
         fd.write(content)
         # Make sure the data hits the disk.
         fd.flush()
-        if self.dofsync:
+        if self.dofsync():
             os.fsync(fd)
         fd.close()
 
